@@ -113,15 +113,21 @@ RESPONSECODE IFDHCreateChannel ( DWORD Lun, DWORD Channel ) {
     syslog(LOG_INFO, "==============================================\n");
 #endif
 
+    /*
     if (Lnibble != 0x3F8 && Lnibble != 0x2F8 && Lnibble != 0x3E8 && Lnibble != 0x2E8) {
 #ifdef ASE_DEBUG
        	syslog(LOG_INFO, "IFDHCreateChannel: Error! Channel not supported. Existing.\n");
 #endif
         return IFD_NOT_SUPPORTED;
     }
+    */
 
     /* open the communication port */
-    sprintf(name, "/dev/ttyS%d", (Lnibble == 0x3F8 ? 0 : Lnibble == 0x2F8 ? 1 : Lnibble == 0x3E8 ? 2 : 3));
+    if (Lnibble == 0x3F8 || Lnibble == 0x2F8 || Lnibble == 0x3E8 || Lnibble == 0x2E8)
+	sprintf(name, "/dev/ttyS%d", (Lnibble == 0x3F8 ? 0 : Lnibble == 0x2F8 ? 1 : Lnibble == 0x3E8 ? 2 : 3));
+    else
+	sprintf(name, "/dev/ttyUSB%d", Lnibble);
+
 
     if (IO_InitializePort(&readerData[readerNum], 115200, 8, 'N', name) == TRUE) {
 #ifdef ASE_DEBUG
