@@ -663,7 +663,7 @@ RESPONSECODE IFDHTransmitToICC ( DWORD Lun, SCARD_IO_HEADER SendPci,
                             unsigned short newLen = (TxBuffer[TxLength - 1] == 0 ? 256 : TxBuffer[TxLength - 1]);
 			                UCHAR Le = (newLen < response[1] ? (newLen == 256 ? 0 : newLen) : response[1]);
                             UCHAR getResponseCmd[5] = {0x00, 0xC0, 0x00, 0x00, 0x00};
-			    getResponseCmd[0] = TxBuffer[0];
+			   // getResponseCmd[0] = TxBuffer[0];
 			    getResponseCmd[4] = Le;
                             
                             retVal = T0Read(&readerData[readerNum], socket, getResponseCmd, 5, response, &actual);
